@@ -4,7 +4,6 @@
 #' @param given_name (character) given name
 #' @param family_name (character) family name
 #' @param past_inst (character) past institution
-#' @param current_prim_inst (character) current primary institution
 #' @param current_inst (character) current institution
 #' @param affiliation_org (character) affiliation organization name
 #' @param ringgold_org_id (character) ringgold organization id
@@ -15,7 +14,6 @@
 #' @param digital_object_ids (character) digital object ids
 #' @param work_title (character) work title
 #' @param grant_number (character) grant number
-#' @param patent_number (character) patent number
 #' @param keywords (character) keywords to search. character vector, one
 #' or more keywords
 #' @param text (character) text to search
@@ -32,6 +30,9 @@
 #'
 #' If no results are found, an empty (0 rows) data.frame
 #' is returned
+#' 
+#' @note `current_prim_inst` and `patent_number` parameters have been
+#' removed as ORCID has removed them
 #'
 #' @details The goal of this function is to make a human friendly
 #' way to search ORCID.
@@ -56,23 +57,25 @@
 #' orcid_search(affiliation_org = '("Boston University" OR BU)')
 #' orcid_search(ringgold_org_id = '1438')
 #' orcid_search(grid_org_id = 'grid.5509.9')
+#' orcid_search(current_inst = '')
+#' orcid_search(email = '*@orcid.org')
 #' orcid_search(given_name = "carl", verbose = TRUE)
 #' }
 orcid_search <- function(given_name = NULL, family_name = NULL,
-    past_inst = NULL, current_prim_inst = NULL, current_inst = NULL,
+    past_inst = NULL, current_inst = NULL,
     affiliation_org = NULL, ringgold_org_id = NULL, grid_org_id = NULL,
     credit_name = NULL, other_name = NULL,
     email = NULL, digital_object_ids = NULL, work_title = NULL,
-    grant_number = NULL, patent_number = NULL, keywords = NULL,
+    grant_number = NULL, keywords = NULL,
     text = NULL, rows = 10, start = NULL, ...) {
 
   query <- ocom(list(given_name = given_name, family_name = family_name,
-    past_inst = past_inst, current_prim_inst = current_prim_inst,
+    past_inst = past_inst,
     current_inst = current_inst, affiliation_org = affiliation_org,
     ringgold_org_id = ringgold_org_id, grid_org_id = grid_org_id,
     credit_name = credit_name, other_name = other_name, email = email,
     digital_object_ids = digital_object_ids, work_title = work_title,
-    grant_number = grant_number, patent_number = patent_number,
+    grant_number = grant_number,
     text = text))
   if (length(query) == 0 && is.null(keywords))
     stop("must pass at least one param")
@@ -104,7 +107,6 @@ field_match_list <- list(
   given_name = 'given-names',
   family_name = 'family-name',
   past_inst = 'past-institution-affiliation-name',
-  current_prim_inst = 'current-primary-institution-affiliation-name',
   current_inst = 'current-institution-affiliation-name',
   affiliation_org = 'affiliation-org-name',
   ringgold_org_id = 'ringgold-org-id',
@@ -115,6 +117,5 @@ field_match_list <- list(
   digital_object_ids = 'digital-object-ids',
   work_title = 'work-titles',
   grant_number = 'grant-numbers',
-  patent_number = 'patent-numbers',
   text = 'text'
 )
